# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='core.proto',
  package='org.dash.platform.dapi.v0',
  syntax='proto3',
  serialized_pb=_b('\n\ncore.proto\x12\x19org.dash.platform.dapi.v0\"\x12\n\x10GetStatusRequest\"\xe5\x01\n\x11GetStatusResponse\x12\x14\n\x0c\x63ore_version\x18\x01 \x01(\r\x12\x18\n\x10protocol_version\x18\x02 \x01(\r\x12\x0e\n\x06\x62locks\x18\x03 \x01(\r\x12\x13\n\x0btime_offset\x18\x04 \x01(\r\x12\x13\n\x0b\x63onnections\x18\x05 \x01(\r\x12\r\n\x05proxy\x18\x06 \x01(\t\x12\x12\n\ndifficulty\x18\x07 \x01(\x01\x12\x0f\n\x07testnet\x18\x08 \x01(\x08\x12\x11\n\trelay_fee\x18\t \x01(\x01\x12\x0e\n\x06\x65rrors\x18\n \x01(\t\x12\x0f\n\x07network\x18\x0b \x01(\t\"<\n\x0fGetBlockRequest\x12\x10\n\x06height\x18\x01 \x01(\rH\x00\x12\x0e\n\x04hash\x18\x02 \x01(\tH\x00\x42\x07\n\x05\x62lock\"!\n\x10GetBlockResponse\x12\r\n\x05\x62lock\x18\x01 \x01(\x0c\"]\n\x16SendTransactionRequest\x12\x13\n\x0btransaction\x18\x01 \x01(\x0c\x12\x17\n\x0f\x61llow_high_fees\x18\x02 \x01(\x08\x12\x15\n\rbypass_limits\x18\x03 \x01(\x08\"1\n\x17SendTransactionResponse\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\"#\n\x15GetTransactionRequest\x12\n\n\x02id\x18\x01 \x01(\t\"-\n\x16GetTransactionResponse\x12\x13\n\x0btransaction\x18\x01 \x01(\x0c\"x\n!BlockHeadersWithChainLocksRequest\x12\x19\n\x0f\x66rom_block_hash\x18\x01 \x01(\x0cH\x00\x12\x1b\n\x11\x66rom_block_height\x18\x02 \x01(\rH\x00\x12\r\n\x05\x63ount\x18\x03 \x01(\rB\x0c\n\nfrom_block\"\xd3\x01\n\"BlockHeadersWithChainLocksResponse\x12@\n\rblock_headers\x18\x01 \x01(\x0b\x32\'.org.dash.platform.dapi.v0.BlockHeadersH\x00\x12^\n\x1d\x63hain_lock_signature_messages\x18\x02 \x01(\x0b\x32\x35.org.dash.platform.dapi.v0.ChainLockSignatureMessagesH\x00\x42\x0b\n\tresponses\"\x1f\n\x0c\x42lockHeaders\x12\x0f\n\x07headers\x18\x01 \x03(\x0c\".\n\x1a\x43hainLockSignatureMessages\x12\x10\n\x08messages\x18\x01 \x03(\x0c\"3\n!GetEstimatedTransactionFeeRequest\x12\x0e\n\x06\x62locks\x18\x01 \x01(\r\"1\n\"GetEstimatedTransactionFeeResponse\x12\x0b\n\x03\x66\x65\x65\x18\x01 \x01(\x01\x32\x89\x06\n\x04\x43ore\x12\x66\n\tgetStatus\x12+.org.dash.platform.dapi.v0.GetStatusRequest\x1a,.org.dash.platform.dapi.v0.GetStatusResponse\x12\x63\n\x08getBlock\x12*.org.dash.platform.dapi.v0.GetBlockRequest\x1a+.org.dash.platform.dapi.v0.GetBlockResponse\x12x\n\x0fsendTransaction\x12\x31.org.dash.platform.dapi.v0.SendTransactionRequest\x1a\x32.org.dash.platform.dapi.v0.SendTransactionResponse\x12u\n\x0egetTransaction\x12\x30.org.dash.platform.dapi.v0.GetTransactionRequest\x1a\x31.org.dash.platform.dapi.v0.GetTransactionResponse\x12\x99\x01\n\x1agetEstimatedTransactionFee\x12<.org.dash.platform.dapi.v0.GetEstimatedTransactionFeeRequest\x1a=.org.dash.platform.dapi.v0.GetEstimatedTransactionFeeResponse\x12\xa6\x01\n%subscribeToBlockHeadersWithChainLocks\x12<.org.dash.platform.dapi.v0.BlockHeadersWithChainLocksRequest\x1a=.org.dash.platform.dapi.v0.BlockHeadersWithChainLocksResponse0\x01\x62\x06proto3')
)




_GETSTATUSREQUEST = _descriptor.Descriptor(
  name='GetStatusRequest',
  full_name='org.dash.platform.dapi.v0.GetStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=59,
)


_GETSTATUSRESPONSE = _descriptor.Descriptor(
  name='GetStatusResponse',
  full_name='org.dash.platform.dapi.v0.GetStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='core_version', full_name='org.dash.platform.dapi.v0.GetStatusResponse.core_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='org.dash.platform.dapi.v0.GetStatusResponse.protocol_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blocks', full_name='org.dash.platform.dapi.v0.GetStatusResponse.blocks', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_offset', full_name='org.dash.platform.dapi.v0.GetStatusResponse.time_offset', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='connections', full_name='org.dash.platform.dapi.v0.GetStatusResponse.connections', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='proxy', full_name='org.dash.platform.dapi.v0.GetStatusResponse.proxy', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='difficulty', full_name='org.dash.platform.dapi.v0.GetStatusResponse.difficulty', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='testnet', full_name='org.dash.platform.dapi.v0.GetStatusResponse.testnet', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='relay_fee', full_name='org.dash.platform.dapi.v0.GetStatusResponse.relay_fee', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='errors', full_name='org.dash.platform.dapi.v0.GetStatusResponse.errors', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='network', full_name='org.dash.platform.dapi.v0.GetStatusResponse.network', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=291,
)


_GETBLOCKREQUEST = _descriptor.Descriptor(
  name='GetBlockRequest',
  full_name='org.dash.platform.dapi.v0.GetBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='org.dash.platform.dapi.v0.GetBlockRequest.height', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hash', full_name='org.dash.platform.dapi.v0.GetBlockRequest.hash', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='block', full_name='org.dash.platform.dapi.v0.GetBlockRequest.block',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=293,
  serialized_end=353,
)


_GETBLOCKRESPONSE = _descriptor.Descriptor(
  name='GetBlockResponse',
  full_name='org.dash.platform.dapi.v0.GetBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='org.dash.platform.dapi.v0.GetBlockResponse.block', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=355,
  serialized_end=388,
)


_SENDTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='SendTransactionRequest',
  full_name='org.dash.platform.dapi.v0.SendTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction', full_name='org.dash.platform.dapi.v0.SendTransactionRequest.transaction', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='allow_high_fees', full_name='org.dash.platform.dapi.v0.SendTransactionRequest.allow_high_fees', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bypass_limits', full_name='org.dash.platform.dapi.v0.SendTransactionRequest.bypass_limits', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=390,
  serialized_end=483,
)


_SENDTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='SendTransactionResponse',
  full_name='org.dash.platform.dapi.v0.SendTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='org.dash.platform.dapi.v0.SendTransactionResponse.transaction_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=485,
  serialized_end=534,
)


_GETTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='GetTransactionRequest',
  full_name='org.dash.platform.dapi.v0.GetTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='org.dash.platform.dapi.v0.GetTransactionRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=571,
)


_GETTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='GetTransactionResponse',
  full_name='org.dash.platform.dapi.v0.GetTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction', full_name='org.dash.platform.dapi.v0.GetTransactionResponse.transaction', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=573,
  serialized_end=618,
)


_BLOCKHEADERSWITHCHAINLOCKSREQUEST = _descriptor.Descriptor(
  name='BlockHeadersWithChainLocksRequest',
  full_name='org.dash.platform.dapi.v0.BlockHeadersWithChainLocksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_block_hash', full_name='org.dash.platform.dapi.v0.BlockHeadersWithChainLocksRequest.from_block_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='from_block_height', full_name='org.dash.platform.dapi.v0.BlockHeadersWithChainLocksRequest.from_block_height', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='count', full_name='org.dash.platform.dapi.v0.BlockHeadersWithChainLocksRequest.count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='from_block', full_name='org.dash.platform.dapi.v0.BlockHeadersWithChainLocksRequest.from_block',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=620,
  serialized_end=740,
)


_BLOCKHEADERSWITHCHAINLOCKSRESPONSE = _descriptor.Descriptor(
  name='BlockHeadersWithChainLocksResponse',
  full_name='org.dash.platform.dapi.v0.BlockHeadersWithChainLocksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_headers', full_name='org.dash.platform.dapi.v0.BlockHeadersWithChainLocksResponse.block_headers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='chain_lock_signature_messages', full_name='org.dash.platform.dapi.v0.BlockHeadersWithChainLocksResponse.chain_lock_signature_messages', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='responses', full_name='org.dash.platform.dapi.v0.BlockHeadersWithChainLocksResponse.responses',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=743,
  serialized_end=954,
)


_BLOCKHEADERS = _descriptor.Descriptor(
  name='BlockHeaders',
  full_name='org.dash.platform.dapi.v0.BlockHeaders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='headers', full_name='org.dash.platform.dapi.v0.BlockHeaders.headers', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=956,
  serialized_end=987,
)


_CHAINLOCKSIGNATUREMESSAGES = _descriptor.Descriptor(
  name='ChainLockSignatureMessages',
  full_name='org.dash.platform.dapi.v0.ChainLockSignatureMessages',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='org.dash.platform.dapi.v0.ChainLockSignatureMessages.messages', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=989,
  serialized_end=1035,
)


_GETESTIMATEDTRANSACTIONFEEREQUEST = _descriptor.Descriptor(
  name='GetEstimatedTransactionFeeRequest',
  full_name='org.dash.platform.dapi.v0.GetEstimatedTransactionFeeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blocks', full_name='org.dash.platform.dapi.v0.GetEstimatedTransactionFeeRequest.blocks', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1037,
  serialized_end=1088,
)


_GETESTIMATEDTRANSACTIONFEERESPONSE = _descriptor.Descriptor(
  name='GetEstimatedTransactionFeeResponse',
  full_name='org.dash.platform.dapi.v0.GetEstimatedTransactionFeeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fee', full_name='org.dash.platform.dapi.v0.GetEstimatedTransactionFeeResponse.fee', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1090,
  serialized_end=1139,
)

_GETBLOCKREQUEST.oneofs_by_name['block'].fields.append(
  _GETBLOCKREQUEST.fields_by_name['height'])
_GETBLOCKREQUEST.fields_by_name['height'].containing_oneof = _GETBLOCKREQUEST.oneofs_by_name['block']
_GETBLOCKREQUEST.oneofs_by_name['block'].fields.append(
  _GETBLOCKREQUEST.fields_by_name['hash'])
_GETBLOCKREQUEST.fields_by_name['hash'].containing_oneof = _GETBLOCKREQUEST.oneofs_by_name['block']
_BLOCKHEADERSWITHCHAINLOCKSREQUEST.oneofs_by_name['from_block'].fields.append(
  _BLOCKHEADERSWITHCHAINLOCKSREQUEST.fields_by_name['from_block_hash'])
_BLOCKHEADERSWITHCHAINLOCKSREQUEST.fields_by_name['from_block_hash'].containing_oneof = _BLOCKHEADERSWITHCHAINLOCKSREQUEST.oneofs_by_name['from_block']
_BLOCKHEADERSWITHCHAINLOCKSREQUEST.oneofs_by_name['from_block'].fields.append(
  _BLOCKHEADERSWITHCHAINLOCKSREQUEST.fields_by_name['from_block_height'])
_BLOCKHEADERSWITHCHAINLOCKSREQUEST.fields_by_name['from_block_height'].containing_oneof = _BLOCKHEADERSWITHCHAINLOCKSREQUEST.oneofs_by_name['from_block']
_BLOCKHEADERSWITHCHAINLOCKSRESPONSE.fields_by_name['block_headers'].message_type = _BLOCKHEADERS
_BLOCKHEADERSWITHCHAINLOCKSRESPONSE.fields_by_name['chain_lock_signature_messages'].message_type = _CHAINLOCKSIGNATUREMESSAGES
_BLOCKHEADERSWITHCHAINLOCKSRESPONSE.oneofs_by_name['responses'].fields.append(
  _BLOCKHEADERSWITHCHAINLOCKSRESPONSE.fields_by_name['block_headers'])
_BLOCKHEADERSWITHCHAINLOCKSRESPONSE.fields_by_name['block_headers'].containing_oneof = _BLOCKHEADERSWITHCHAINLOCKSRESPONSE.oneofs_by_name['responses']
_BLOCKHEADERSWITHCHAINLOCKSRESPONSE.oneofs_by_name['responses'].fields.append(
  _BLOCKHEADERSWITHCHAINLOCKSRESPONSE.fields_by_name['chain_lock_signature_messages'])
_BLOCKHEADERSWITHCHAINLOCKSRESPONSE.fields_by_name['chain_lock_signature_messages'].containing_oneof = _BLOCKHEADERSWITHCHAINLOCKSRESPONSE.oneofs_by_name['responses']
DESCRIPTOR.message_types_by_name['GetStatusRequest'] = _GETSTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetStatusResponse'] = _GETSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['GetBlockRequest'] = _GETBLOCKREQUEST
DESCRIPTOR.message_types_by_name['GetBlockResponse'] = _GETBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['SendTransactionRequest'] = _SENDTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['SendTransactionResponse'] = _SENDTRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['GetTransactionRequest'] = _GETTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['GetTransactionResponse'] = _GETTRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['BlockHeadersWithChainLocksRequest'] = _BLOCKHEADERSWITHCHAINLOCKSREQUEST
DESCRIPTOR.message_types_by_name['BlockHeadersWithChainLocksResponse'] = _BLOCKHEADERSWITHCHAINLOCKSRESPONSE
DESCRIPTOR.message_types_by_name['BlockHeaders'] = _BLOCKHEADERS
DESCRIPTOR.message_types_by_name['ChainLockSignatureMessages'] = _CHAINLOCKSIGNATUREMESSAGES
DESCRIPTOR.message_types_by_name['GetEstimatedTransactionFeeRequest'] = _GETESTIMATEDTRANSACTIONFEEREQUEST
DESCRIPTOR.message_types_by_name['GetEstimatedTransactionFeeResponse'] = _GETESTIMATEDTRANSACTIONFEERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetStatusRequest = _reflection.GeneratedProtocolMessageType('GetStatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETSTATUSREQUEST,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:org.dash.platform.dapi.v0.GetStatusRequest)
  ))
_sym_db.RegisterMessage(GetStatusRequest)

GetStatusResponse = _reflection.GeneratedProtocolMessageType('GetStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETSTATUSRESPONSE,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:org.dash.platform.dapi.v0.GetStatusResponse)
  ))
_sym_db.RegisterMessage(GetStatusResponse)

GetBlockRequest = _reflection.GeneratedProtocolMessageType('GetBlockRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBLOCKREQUEST,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:org.dash.platform.dapi.v0.GetBlockRequest)
  ))
_sym_db.RegisterMessage(GetBlockRequest)

GetBlockResponse = _reflection.GeneratedProtocolMessageType('GetBlockResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETBLOCKRESPONSE,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:org.dash.platform.dapi.v0.GetBlockResponse)
  ))
_sym_db.RegisterMessage(GetBlockResponse)

SendTransactionRequest = _reflection.GeneratedProtocolMessageType('SendTransactionRequest', (_message.Message,), dict(
  DESCRIPTOR = _SENDTRANSACTIONREQUEST,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:org.dash.platform.dapi.v0.SendTransactionRequest)
  ))
_sym_db.RegisterMessage(SendTransactionRequest)

SendTransactionResponse = _reflection.GeneratedProtocolMessageType('SendTransactionResponse', (_message.Message,), dict(
  DESCRIPTOR = _SENDTRANSACTIONRESPONSE,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:org.dash.platform.dapi.v0.SendTransactionResponse)
  ))
_sym_db.RegisterMessage(SendTransactionResponse)

GetTransactionRequest = _reflection.GeneratedProtocolMessageType('GetTransactionRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETTRANSACTIONREQUEST,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:org.dash.platform.dapi.v0.GetTransactionRequest)
  ))
_sym_db.RegisterMessage(GetTransactionRequest)

GetTransactionResponse = _reflection.GeneratedProtocolMessageType('GetTransactionResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETTRANSACTIONRESPONSE,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:org.dash.platform.dapi.v0.GetTransactionResponse)
  ))
_sym_db.RegisterMessage(GetTransactionResponse)

BlockHeadersWithChainLocksRequest = _reflection.GeneratedProtocolMessageType('BlockHeadersWithChainLocksRequest', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKHEADERSWITHCHAINLOCKSREQUEST,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:org.dash.platform.dapi.v0.BlockHeadersWithChainLocksRequest)
  ))
_sym_db.RegisterMessage(BlockHeadersWithChainLocksRequest)

BlockHeadersWithChainLocksResponse = _reflection.GeneratedProtocolMessageType('BlockHeadersWithChainLocksResponse', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKHEADERSWITHCHAINLOCKSRESPONSE,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:org.dash.platform.dapi.v0.BlockHeadersWithChainLocksResponse)
  ))
_sym_db.RegisterMessage(BlockHeadersWithChainLocksResponse)

BlockHeaders = _reflection.GeneratedProtocolMessageType('BlockHeaders', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKHEADERS,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:org.dash.platform.dapi.v0.BlockHeaders)
  ))
_sym_db.RegisterMessage(BlockHeaders)

ChainLockSignatureMessages = _reflection.GeneratedProtocolMessageType('ChainLockSignatureMessages', (_message.Message,), dict(
  DESCRIPTOR = _CHAINLOCKSIGNATUREMESSAGES,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:org.dash.platform.dapi.v0.ChainLockSignatureMessages)
  ))
_sym_db.RegisterMessage(ChainLockSignatureMessages)

GetEstimatedTransactionFeeRequest = _reflection.GeneratedProtocolMessageType('GetEstimatedTransactionFeeRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETESTIMATEDTRANSACTIONFEEREQUEST,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:org.dash.platform.dapi.v0.GetEstimatedTransactionFeeRequest)
  ))
_sym_db.RegisterMessage(GetEstimatedTransactionFeeRequest)

GetEstimatedTransactionFeeResponse = _reflection.GeneratedProtocolMessageType('GetEstimatedTransactionFeeResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETESTIMATEDTRANSACTIONFEERESPONSE,
  __module__ = 'core_pb2'
  # @@protoc_insertion_point(class_scope:org.dash.platform.dapi.v0.GetEstimatedTransactionFeeResponse)
  ))
_sym_db.RegisterMessage(GetEstimatedTransactionFeeResponse)



_CORE = _descriptor.ServiceDescriptor(
  name='Core',
  full_name='org.dash.platform.dapi.v0.Core',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=1142,
  serialized_end=1919,
  methods=[
  _descriptor.MethodDescriptor(
    name='getStatus',
    full_name='org.dash.platform.dapi.v0.Core.getStatus',
    index=0,
    containing_service=None,
    input_type=_GETSTATUSREQUEST,
    output_type=_GETSTATUSRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getBlock',
    full_name='org.dash.platform.dapi.v0.Core.getBlock',
    index=1,
    containing_service=None,
    input_type=_GETBLOCKREQUEST,
    output_type=_GETBLOCKRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='sendTransaction',
    full_name='org.dash.platform.dapi.v0.Core.sendTransaction',
    index=2,
    containing_service=None,
    input_type=_SENDTRANSACTIONREQUEST,
    output_type=_SENDTRANSACTIONRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getTransaction',
    full_name='org.dash.platform.dapi.v0.Core.getTransaction',
    index=3,
    containing_service=None,
    input_type=_GETTRANSACTIONREQUEST,
    output_type=_GETTRANSACTIONRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getEstimatedTransactionFee',
    full_name='org.dash.platform.dapi.v0.Core.getEstimatedTransactionFee',
    index=4,
    containing_service=None,
    input_type=_GETESTIMATEDTRANSACTIONFEEREQUEST,
    output_type=_GETESTIMATEDTRANSACTIONFEERESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='subscribeToBlockHeadersWithChainLocks',
    full_name='org.dash.platform.dapi.v0.Core.subscribeToBlockHeadersWithChainLocks',
    index=5,
    containing_service=None,
    input_type=_BLOCKHEADERSWITHCHAINLOCKSREQUEST,
    output_type=_BLOCKHEADERSWITHCHAINLOCKSRESPONSE,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CORE)

DESCRIPTOR.services_by_name['Core'] = _CORE

try:
  # THESE ELEMENTS WILL BE DEPRECATED.
  # Please use the generated *_pb2_grpc.py files instead.
  import grpc
  from grpc.beta import implementations as beta_implementations
  from grpc.beta import interfaces as beta_interfaces
  from grpc.framework.common import cardinality
  from grpc.framework.interfaces.face import utilities as face_utilities


  class CoreStub(object):
    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
      """Constructor.

      Args:
        channel: A grpc.Channel.
      """
      self.getStatus = channel.unary_unary(
          '/org.dash.platform.dapi.v0.Core/getStatus',
          request_serializer=GetStatusRequest.SerializeToString,
          response_deserializer=GetStatusResponse.FromString,
          )
      self.getBlock = channel.unary_unary(
          '/org.dash.platform.dapi.v0.Core/getBlock',
          request_serializer=GetBlockRequest.SerializeToString,
          response_deserializer=GetBlockResponse.FromString,
          )
      self.sendTransaction = channel.unary_unary(
          '/org.dash.platform.dapi.v0.Core/sendTransaction',
          request_serializer=SendTransactionRequest.SerializeToString,
          response_deserializer=SendTransactionResponse.FromString,
          )
      self.getTransaction = channel.unary_unary(
          '/org.dash.platform.dapi.v0.Core/getTransaction',
          request_serializer=GetTransactionRequest.SerializeToString,
          response_deserializer=GetTransactionResponse.FromString,
          )
      self.getEstimatedTransactionFee = channel.unary_unary(
          '/org.dash.platform.dapi.v0.Core/getEstimatedTransactionFee',
          request_serializer=GetEstimatedTransactionFeeRequest.SerializeToString,
          response_deserializer=GetEstimatedTransactionFeeResponse.FromString,
          )
      self.subscribeToBlockHeadersWithChainLocks = channel.unary_stream(
          '/org.dash.platform.dapi.v0.Core/subscribeToBlockHeadersWithChainLocks',
          request_serializer=BlockHeadersWithChainLocksRequest.SerializeToString,
          response_deserializer=BlockHeadersWithChainLocksResponse.FromString,
          )


  class CoreServicer(object):
    # missing associated documentation comment in .proto file
    pass

    def getStatus(self, request, context):
      # missing associated documentation comment in .proto file
      pass
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def getBlock(self, request, context):
      # missing associated documentation comment in .proto file
      pass
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def sendTransaction(self, request, context):
      # missing associated documentation comment in .proto file
      pass
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def getTransaction(self, request, context):
      # missing associated documentation comment in .proto file
      pass
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def getEstimatedTransactionFee(self, request, context):
      # missing associated documentation comment in .proto file
      pass
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def subscribeToBlockHeadersWithChainLocks(self, request, context):
      # missing associated documentation comment in .proto file
      pass
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')


  def add_CoreServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'getStatus': grpc.unary_unary_rpc_method_handler(
            servicer.getStatus,
            request_deserializer=GetStatusRequest.FromString,
            response_serializer=GetStatusResponse.SerializeToString,
        ),
        'getBlock': grpc.unary_unary_rpc_method_handler(
            servicer.getBlock,
            request_deserializer=GetBlockRequest.FromString,
            response_serializer=GetBlockResponse.SerializeToString,
        ),
        'sendTransaction': grpc.unary_unary_rpc_method_handler(
            servicer.sendTransaction,
            request_deserializer=SendTransactionRequest.FromString,
            response_serializer=SendTransactionResponse.SerializeToString,
        ),
        'getTransaction': grpc.unary_unary_rpc_method_handler(
            servicer.getTransaction,
            request_deserializer=GetTransactionRequest.FromString,
            response_serializer=GetTransactionResponse.SerializeToString,
        ),
        'getEstimatedTransactionFee': grpc.unary_unary_rpc_method_handler(
            servicer.getEstimatedTransactionFee,
            request_deserializer=GetEstimatedTransactionFeeRequest.FromString,
            response_serializer=GetEstimatedTransactionFeeResponse.SerializeToString,
        ),
        'subscribeToBlockHeadersWithChainLocks': grpc.unary_stream_rpc_method_handler(
            servicer.subscribeToBlockHeadersWithChainLocks,
            request_deserializer=BlockHeadersWithChainLocksRequest.FromString,
            response_serializer=BlockHeadersWithChainLocksResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'org.dash.platform.dapi.v0.Core', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


  class BetaCoreServicer(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    # missing associated documentation comment in .proto file
    pass
    def getStatus(self, request, context):
      # missing associated documentation comment in .proto file
      pass
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def getBlock(self, request, context):
      # missing associated documentation comment in .proto file
      pass
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def sendTransaction(self, request, context):
      # missing associated documentation comment in .proto file
      pass
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def getTransaction(self, request, context):
      # missing associated documentation comment in .proto file
      pass
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def getEstimatedTransactionFee(self, request, context):
      # missing associated documentation comment in .proto file
      pass
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def subscribeToBlockHeadersWithChainLocks(self, request, context):
      # missing associated documentation comment in .proto file
      pass
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)


  class BetaCoreStub(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    # missing associated documentation comment in .proto file
    pass
    def getStatus(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      # missing associated documentation comment in .proto file
      pass
      raise NotImplementedError()
    getStatus.future = None
    def getBlock(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      # missing associated documentation comment in .proto file
      pass
      raise NotImplementedError()
    getBlock.future = None
    def sendTransaction(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      # missing associated documentation comment in .proto file
      pass
      raise NotImplementedError()
    sendTransaction.future = None
    def getTransaction(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      # missing associated documentation comment in .proto file
      pass
      raise NotImplementedError()
    getTransaction.future = None
    def getEstimatedTransactionFee(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      # missing associated documentation comment in .proto file
      pass
      raise NotImplementedError()
    getEstimatedTransactionFee.future = None
    def subscribeToBlockHeadersWithChainLocks(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      # missing associated documentation comment in .proto file
      pass
      raise NotImplementedError()


  def beta_create_Core_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_deserializers = {
      ('org.dash.platform.dapi.v0.Core', 'getBlock'): GetBlockRequest.FromString,
      ('org.dash.platform.dapi.v0.Core', 'getEstimatedTransactionFee'): GetEstimatedTransactionFeeRequest.FromString,
      ('org.dash.platform.dapi.v0.Core', 'getStatus'): GetStatusRequest.FromString,
      ('org.dash.platform.dapi.v0.Core', 'getTransaction'): GetTransactionRequest.FromString,
      ('org.dash.platform.dapi.v0.Core', 'sendTransaction'): SendTransactionRequest.FromString,
      ('org.dash.platform.dapi.v0.Core', 'subscribeToBlockHeadersWithChainLocks'): BlockHeadersWithChainLocksRequest.FromString,
    }
    response_serializers = {
      ('org.dash.platform.dapi.v0.Core', 'getBlock'): GetBlockResponse.SerializeToString,
      ('org.dash.platform.dapi.v0.Core', 'getEstimatedTransactionFee'): GetEstimatedTransactionFeeResponse.SerializeToString,
      ('org.dash.platform.dapi.v0.Core', 'getStatus'): GetStatusResponse.SerializeToString,
      ('org.dash.platform.dapi.v0.Core', 'getTransaction'): GetTransactionResponse.SerializeToString,
      ('org.dash.platform.dapi.v0.Core', 'sendTransaction'): SendTransactionResponse.SerializeToString,
      ('org.dash.platform.dapi.v0.Core', 'subscribeToBlockHeadersWithChainLocks'): BlockHeadersWithChainLocksResponse.SerializeToString,
    }
    method_implementations = {
      ('org.dash.platform.dapi.v0.Core', 'getBlock'): face_utilities.unary_unary_inline(servicer.getBlock),
      ('org.dash.platform.dapi.v0.Core', 'getEstimatedTransactionFee'): face_utilities.unary_unary_inline(servicer.getEstimatedTransactionFee),
      ('org.dash.platform.dapi.v0.Core', 'getStatus'): face_utilities.unary_unary_inline(servicer.getStatus),
      ('org.dash.platform.dapi.v0.Core', 'getTransaction'): face_utilities.unary_unary_inline(servicer.getTransaction),
      ('org.dash.platform.dapi.v0.Core', 'sendTransaction'): face_utilities.unary_unary_inline(servicer.sendTransaction),
      ('org.dash.platform.dapi.v0.Core', 'subscribeToBlockHeadersWithChainLocks'): face_utilities.unary_stream_inline(servicer.subscribeToBlockHeadersWithChainLocks),
    }
    server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
    return beta_implementations.server(method_implementations, options=server_options)


  def beta_create_Core_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_serializers = {
      ('org.dash.platform.dapi.v0.Core', 'getBlock'): GetBlockRequest.SerializeToString,
      ('org.dash.platform.dapi.v0.Core', 'getEstimatedTransactionFee'): GetEstimatedTransactionFeeRequest.SerializeToString,
      ('org.dash.platform.dapi.v0.Core', 'getStatus'): GetStatusRequest.SerializeToString,
      ('org.dash.platform.dapi.v0.Core', 'getTransaction'): GetTransactionRequest.SerializeToString,
      ('org.dash.platform.dapi.v0.Core', 'sendTransaction'): SendTransactionRequest.SerializeToString,
      ('org.dash.platform.dapi.v0.Core', 'subscribeToBlockHeadersWithChainLocks'): BlockHeadersWithChainLocksRequest.SerializeToString,
    }
    response_deserializers = {
      ('org.dash.platform.dapi.v0.Core', 'getBlock'): GetBlockResponse.FromString,
      ('org.dash.platform.dapi.v0.Core', 'getEstimatedTransactionFee'): GetEstimatedTransactionFeeResponse.FromString,
      ('org.dash.platform.dapi.v0.Core', 'getStatus'): GetStatusResponse.FromString,
      ('org.dash.platform.dapi.v0.Core', 'getTransaction'): GetTransactionResponse.FromString,
      ('org.dash.platform.dapi.v0.Core', 'sendTransaction'): SendTransactionResponse.FromString,
      ('org.dash.platform.dapi.v0.Core', 'subscribeToBlockHeadersWithChainLocks'): BlockHeadersWithChainLocksResponse.FromString,
    }
    cardinalities = {
      'getBlock': cardinality.Cardinality.UNARY_UNARY,
      'getEstimatedTransactionFee': cardinality.Cardinality.UNARY_UNARY,
      'getStatus': cardinality.Cardinality.UNARY_UNARY,
      'getTransaction': cardinality.Cardinality.UNARY_UNARY,
      'sendTransaction': cardinality.Cardinality.UNARY_UNARY,
      'subscribeToBlockHeadersWithChainLocks': cardinality.Cardinality.UNARY_STREAM,
    }
    stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
    return beta_implementations.dynamic_stub(channel, 'org.dash.platform.dapi.v0.Core', cardinalities, options=stub_options)
except ImportError:
  pass
# @@protoc_insertion_point(module_scope)



import requests
import json

RPC_VERSION = '2.0'

class JsonRpcClient:

    def __init__(self):
        return


    def request(url, method, params = {}, options = {}):
        #print(url)
        destination = 'http://{}:{}'.format(url['host'], url['port'])

        payload = {
            'jsonrpc': RPC_VERSION,
            'method': method,
            'params': params,
            'id': 1
            }

        headers = {'content-type': 'application/json'}

        try:
            response = requests.post(destination, data=json.dumps(payload), headers=headers, timeout=1)
            response.raise_for_status()

            parsed = json.loads(response.text)
            #print('{} response:\n{}\n\n'.format(method, json.dumps(parsed, indent=4, sort_keys=True)))
            if 'result' in parsed:
                return parsed['result']
            elif 'error' in parsed:
                return parsed['error']

        except Exception as ex:
            print('Exception for {} - {}\n\t{}'.format(url, payload, ex))
            raise



from logging import Handler
from dapiclient.client import DAPIClient
import cbor2
import base58
from thumbor.handlers.imaging import ImagingHandler
from thumbor_dash.error_handlers.sentry import ErrorHandler
from thumbor_dash.error_handlers import *


def getDocuments(handler, data, seed_ip = None, mn_ip = None):
    client = DAPIClient(seed_ip=seed_ip, mn_ip = mn_ip)

    try:
        docs = client.getDocuments(
             data['contract_id'],
             data['document_type'],
             data['where'],
             limit=2, # Only one document
        )
    except Exception as e:
        return e
    else:
        return docs[0]# Return the only document in the list


def getIdentity(handler, ownerId, seed_ip = None, mn_ip = None):
    client = DAPIClient(seed_ip=seed_ip, mn_ip = mn_ip)

    try:
        identity = client.getIdentity(ownerId)
    except Exception as e:
        return e
    else:   
        return identity # Return the identity




def main():

# Test getIdentity
    ownerId = base58.b58decode("G75gKVaN7BAz8GhKp9qk18o9Mf2JgCpRxLtzYGNs68Wa")
    identity = getIdentity(None,ownerId=ownerId,seed_ip="52.43.162.96", mn_ip="52.11.85.154")
    print(str(identity))

# Test getDocuments
    data = {
        'contract_id': base58.b58decode('HPvdCZ3sr2ACdSW6VeNVKKiYjUBnS4YkMv3sexzzTABJ'),
        'document_type': 'thumbnailField',
        'where': cbor2.dumps([
            ['ownerId', '==', base58.b58decode('G75gKVaN7BAz8GhKp9qk18o9Mf2JgCpRxLtzYGNs68Wa')],
            ['$updatedAt', '==', 1634748218973],
        ]),
    }
    docs = getDocuments(ErrorHandler,data,seed_ip=None, mn_ip="34.219.81.129")    
    print(str(docs))

   
if __name__ == "__main__":
    main()







# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

import dapiclient.rpc.grpc.platform_pb2 as platform__pb2


class PlatformStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.
    Args:
      channel: A grpc.Channel.
    """
    self.broadcastStateTransition = channel.unary_unary(
        '/org.dash.platform.dapi.v0.Platform/broadcastStateTransition',
        request_serializer=platform__pb2.BroadcastStateTransitionRequest.SerializeToString,
        response_deserializer=platform__pb2.BroadcastStateTransitionResponse.FromString,
        )
    self.getIdentity = channel.unary_unary(
        '/org.dash.platform.dapi.v0.Platform/getIdentity',
        request_serializer=platform__pb2.GetIdentityRequest.SerializeToString,
        response_deserializer=platform__pb2.GetIdentityResponse.FromString,
        )
    self.getDataContract = channel.unary_unary(
        '/org.dash.platform.dapi.v0.Platform/getDataContract',
        request_serializer=platform__pb2.GetDataContractRequest.SerializeToString,
        response_deserializer=platform__pb2.GetDataContractResponse.FromString,
        )
    self.getDocuments = channel.unary_unary(
        '/org.dash.platform.dapi.v0.Platform/getDocuments',
        request_serializer=platform__pb2.GetDocumentsRequest.SerializeToString,
        response_deserializer=platform__pb2.GetDocumentsResponse.FromString,
        )
    self.getIdentitiesByPublicKeyHashes = channel.unary_unary(
        '/org.dash.platform.dapi.v0.Platform/getIdentitiesByPublicKeyHashes',
        request_serializer=platform__pb2.GetIdentitiesByPublicKeyHashesRequest.SerializeToString,
        response_deserializer=platform__pb2.GetIdentitiesByPublicKeyHashesResponse.FromString,
        )
    self.getIdentityIdsByPublicKeyHashes = channel.unary_unary(
        '/org.dash.platform.dapi.v0.Platform/getIdentityIdsByPublicKeyHashes',
        request_serializer=platform__pb2.GetIdentityIdsByPublicKeyHashesRequest.SerializeToString,
        response_deserializer=platform__pb2.GetIdentityIdsByPublicKeyHashesResponse.FromString,
        )
    self.waitForStateTransitionResult = channel.unary_unary(
        '/org.dash.platform.dapi.v0.Platform/waitForStateTransitionResult',
        request_serializer=platform__pb2.WaitForStateTransitionResultRequest.SerializeToString,
        response_deserializer=platform__pb2.WaitForStateTransitionResultResponse.FromString,
        )
    self.getConsensusParams = channel.unary_unary(
        '/org.dash.platform.dapi.v0.Platform/getConsensusParams',
        request_serializer=platform__pb2.GetConsensusParamsRequest.SerializeToString,
        response_deserializer=platform__pb2.GetConsensusParamsResponse.FromString,
        )


class PlatformServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def broadcastStateTransition(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def getIdentity(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def getDataContract(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def getDocuments(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def getIdentitiesByPublicKeyHashes(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def getIdentityIdsByPublicKeyHashes(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def waitForStateTransitionResult(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def getConsensusParams(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_PlatformServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'broadcastStateTransition': grpc.unary_unary_rpc_method_handler(
          servicer.broadcastStateTransition,
          request_deserializer=platform__pb2.BroadcastStateTransitionRequest.FromString,
          response_serializer=platform__pb2.BroadcastStateTransitionResponse.SerializeToString,
      ),
      'getIdentity': grpc.unary_unary_rpc_method_handler(
          servicer.getIdentity,
          request_deserializer=platform__pb2.GetIdentityRequest.FromString,
          response_serializer=platform__pb2.GetIdentityResponse.SerializeToString,
      ),
      'getDataContract': grpc.unary_unary_rpc_method_handler(
          servicer.getDataContract,
          request_deserializer=platform__pb2.GetDataContractRequest.FromString,
          response_serializer=platform__pb2.GetDataContractResponse.SerializeToString,
      ),
      'getDocuments': grpc.unary_unary_rpc_method_handler(
          servicer.getDocuments,
          request_deserializer=platform__pb2.GetDocumentsRequest.FromString,
          response_serializer=platform__pb2.GetDocumentsResponse.SerializeToString,
      ),
      'getIdentitiesByPublicKeyHashes': grpc.unary_unary_rpc_method_handler(
          servicer.getIdentitiesByPublicKeyHashes,
          request_deserializer=platform__pb2.GetIdentitiesByPublicKeyHashesRequest.FromString,
          response_serializer=platform__pb2.GetIdentitiesByPublicKeyHashesResponse.SerializeToString,
      ),
      'getIdentityIdsByPublicKeyHashes': grpc.unary_unary_rpc_method_handler(
          servicer.getIdentityIdsByPublicKeyHashes,
          request_deserializer=platform__pb2.GetIdentityIdsByPublicKeyHashesRequest.FromString,
          response_serializer=platform__pb2.GetIdentityIdsByPublicKeyHashesResponse.SerializeToString,
      ),
      'waitForStateTransitionResult': grpc.unary_unary_rpc_method_handler(
          servicer.waitForStateTransitionResult,
          request_deserializer=platform__pb2.WaitForStateTransitionResultRequest.FromString,
          response_serializer=platform__pb2.WaitForStateTransitionResultResponse.SerializeToString,
      ),
      'getConsensusParams': grpc.unary_unary_rpc_method_handler(
          servicer.getConsensusParams,
          request_deserializer=platform__pb2.GetConsensusParamsRequest.FromString,
          response_serializer=platform__pb2.GetConsensusParamsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'org.dash.platform.dapi.v0.Platform', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import core_pb2 as core__pb2


class CoreStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.getStatus = channel.unary_unary(
        '/org.dash.platform.dapi.v0.Core/getStatus',
        request_serializer=core__pb2.GetStatusRequest.SerializeToString,
        response_deserializer=core__pb2.GetStatusResponse.FromString,
        )
    self.getBlock = channel.unary_unary(
        '/org.dash.platform.dapi.v0.Core/getBlock',
        request_serializer=core__pb2.GetBlockRequest.SerializeToString,
        response_deserializer=core__pb2.GetBlockResponse.FromString,
        )
    self.sendTransaction = channel.unary_unary(
        '/org.dash.platform.dapi.v0.Core/sendTransaction',
        request_serializer=core__pb2.SendTransactionRequest.SerializeToString,
        response_deserializer=core__pb2.SendTransactionResponse.FromString,
        )
    self.getTransaction = channel.unary_unary(
        '/org.dash.platform.dapi.v0.Core/getTransaction',
        request_serializer=core__pb2.GetTransactionRequest.SerializeToString,
        response_deserializer=core__pb2.GetTransactionResponse.FromString,
        )
    self.getEstimatedTransactionFee = channel.unary_unary(
        '/org.dash.platform.dapi.v0.Core/getEstimatedTransactionFee',
        request_serializer=core__pb2.GetEstimatedTransactionFeeRequest.SerializeToString,
        response_deserializer=core__pb2.GetEstimatedTransactionFeeResponse.FromString,
        )
    self.subscribeToBlockHeadersWithChainLocks = channel.unary_stream(
        '/org.dash.platform.dapi.v0.Core/subscribeToBlockHeadersWithChainLocks',
        request_serializer=core__pb2.BlockHeadersWithChainLocksRequest.SerializeToString,
        response_deserializer=core__pb2.BlockHeadersWithChainLocksResponse.FromString,
        )


class CoreServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def getStatus(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def getBlock(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def sendTransaction(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def getTransaction(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def getEstimatedTransactionFee(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def subscribeToBlockHeadersWithChainLocks(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CoreServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'getStatus': grpc.unary_unary_rpc_method_handler(
          servicer.getStatus,
          request_deserializer=core__pb2.GetStatusRequest.FromString,
          response_serializer=core__pb2.GetStatusResponse.SerializeToString,
      ),
      'getBlock': grpc.unary_unary_rpc_method_handler(
          servicer.getBlock,
          request_deserializer=core__pb2.GetBlockRequest.FromString,
          response_serializer=core__pb2.GetBlockResponse.SerializeToString,
      ),
      'sendTransaction': grpc.unary_unary_rpc_method_handler(
          servicer.sendTransaction,
          request_deserializer=core__pb2.SendTransactionRequest.FromString,
          response_serializer=core__pb2.SendTransactionResponse.SerializeToString,
      ),
      'getTransaction': grpc.unary_unary_rpc_method_handler(
          servicer.getTransaction,
          request_deserializer=core__pb2.GetTransactionRequest.FromString,
          response_serializer=core__pb2.GetTransactionResponse.SerializeToString,
      ),
      'getEstimatedTransactionFee': grpc.unary_unary_rpc_method_handler(
          servicer.getEstimatedTransactionFee,
          request_deserializer=core__pb2.GetEstimatedTransactionFeeRequest.FromString,
          response_serializer=core__pb2.GetEstimatedTransactionFeeResponse.SerializeToString,
      ),
      'subscribeToBlockHeadersWithChainLocks': grpc.unary_stream_rpc_method_handler(
          servicer.subscribeToBlockHeadersWithChainLocks,
          request_deserializer=core__pb2.BlockHeadersWithChainLocksRequest.FromString,
          response_serializer=core__pb2.BlockHeadersWithChainLocksResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'org.dash.platform.dapi.v0.Core', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import transactions_filter_stream_pb2 as transactions__filter__stream__pb2


class TransactionsFilterStreamStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.subscribeToTransactionsWithProofs = channel.unary_stream(
        '/org.dash.platform.dapi.v0.TransactionsFilterStream/subscribeToTransactionsWithProofs',
        request_serializer=transactions__filter__stream__pb2.TransactionsWithProofsRequest.SerializeToString,
        response_deserializer=transactions__filter__stream__pb2.TransactionsWithProofsResponse.FromString,
        )


class TransactionsFilterStreamServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def subscribeToTransactionsWithProofs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_TransactionsFilterStreamServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'subscribeToTransactionsWithProofs': grpc.unary_stream_rpc_method_handler(
          servicer.subscribeToTransactionsWithProofs,
          request_deserializer=transactions__filter__stream__pb2.TransactionsWithProofsRequest.FromString,
          response_serializer=transactions__filter__stream__pb2.TransactionsWithProofsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'org.dash.platform.dapi.v0.TransactionsFilterStream', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



from .masternode_list_provider import MasternodeListProvider
import random

class MasternodeDiscovery:
    def __init__(self, seeds = None, port = None):
        self.mnlist_provider = MasternodeListProvider(seeds, port)
        self.seeds = seeds


    def get_random_masternode(self, excluded_ips = None):
        mnlist = self.mnlist_provider.get_mn_list()
        return random.sample(mnlist, 1)[0]['service']      

    def get_mnlist(self):
        return self.mnlist_provider.get_mn_list()


    def check_mn_response(self, ip_address):
        return self.mnlist_provider.check_mn_response(ip_address)


    def reset(self):
        self.mnlist_provider = MasternodeListProvider(self.seeds);
